/******************************************************************************
 * function.h - Miscellaneous grab-bag function headers. See function.cpp     *
 *                                                                            *
 *  Copyright (C) Steve Hayes 2011-2013 <steve@honeylink.co.uk>               *
 *                                                                            *
 *  This is free software: you can redistribute it and/or modify it           *
 *  under the terms of the GNU General Public License as published by the     *
 *  Free Software Foundation, either version 3 of the License, or             *
 *  (at your option) any later version.                                       *
 *                                                                            *
 *  It is distributed in the hope that it will be useful, but                 *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of                *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                      *
 *  See the GNU General Public License for more details.                      *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License along   *
 *  with this program.  If not, see <http://www.gnu.org/licenses/>.           *
 ******************************************************************************/

class CSVLine {
   /***************************************************************************
    * This is constructed with a Comma Separated Values formatted line which  *
    * is split into fields by the constructor. Individual fields can then be  *
    * read as strings or integers with default values if they are missing.    *
    ***************************************************************************/
#define MAX_CSVFIELDS 100
   char *buf;                                                    // line buffer
   int
      fpos[MAX_CSVFIELDS],    // starting position of individual fields in lbuf
      nFields;                                        // number of fields found

   public:
   CSVLine(const char *line);         // CONSTRUCTOR is defined in function.cpp

   ~CSVLine() {
      /************************************************************************
       * DESTRUCTOR                                                           *
       ************************************************************************/
      if (buf)
         delete[] buf; }



   /***************************************************************************
    * The following methods return information about field n (starting with   *
    * 0). If the field is missing, defval is returned.                        *
    ***************************************************************************/
   const char* GetFieldAsString(int n, const char* defval) {
      return (n < nFields && buf[fpos[n]]) ?
         &buf[fpos[n]] : defval; }



   int GetFieldAsInt(int n, int defval) {
      return (n < nFields && buf[fpos[n]]) ?
         atoi(&buf[fpos[n]]) : defval; }



   /***************************************************************************
    * The following method returns information about the overall line.        *
    ***************************************************************************/
   int NumberOfFields() {
      return nFields; }
 };



class PathAndName {
   /***************************************************************************
    * This is constructed with a "root" pathname. Methods are provided to     *
    * append a further path and file name and return the result.              *
    ***************************************************************************/
   char buf[MAX_FP_CHARS];                      // holds the path and file name
   int pos;                                 // position of the file name in buf

   public:
   PathAndName(const char *path);     // CONSTRUCTOR is defined in function.cpp
   char *Path(const char *name);
   char *Path(int num, const char *ext);
   char *GetFile();
};


/*
 * These are prototypes for miscellaneous functions.
 */
char opt(char *args[], int maxarg, int *num, int *pos, const char *valopts,
   char *val, int valsize);
int UserConfirm();
char *PathParse(const char *path, char *dest, int destsize, int word, int *pos);
int PathParse(const char *path, int word, int *pos);
char *CSVfield(char *s, int *pos);
char *UnixPath(char *p);
char *EscapePath(char *d, const char *s, int ds, int xl);
char *UnEscapePath(char *d, const char *s);
int FixName(char *s);
int MatchChar(const char *a, const char *b);
int MatchExt(const char *a, const char *b);
int strStartCmp(const char *a, const char *b);
unsigned int RSHash(const char* str);

