/******************************************************************************
 * wordslist.h  - Headers for class that maintains a list of words. See       *
 * wordslist.cpp.                                                             *
 *                                                                            *
 * Copyright (C) Steve Hayes 2011-2013 <steve@honeylink.co.uk>                *
 *                                                                            *
 * This program is free software; you can redistribute it and/or modify it    *
 * under the terms of the GNU General Public License as published by the Free *
 * Software Foundation; either version 2 of the License, or (at your option)  *
 * any later version.                                                         *
 *                                                                            *
 * This program is distributed in the hope that it will be useful, but        *
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License   *
 * for more details.                                                          *
 *                                                                            *
 * You should have received a copy of the GNU General Public License along    *
 * with this program. If not, see <http://www.gnu.org/licenses/>.             *
 ******************************************************************************/



class WordsList {
   /***************************************************************************
    * This implements a list of word hashes. A maximum number of words to     *
    * accommodate is specified when it is constructed. The Set method adds a  *
    * word or increments its count if it is already in the list. There are    *
    * methods to get the count for an individual word or the total number of  *
    * words in the list.                                                      *
    ***************************************************************************/

   struct wordslist {
      int hash,                                         // the hash of the word
         count; }                           // Number of incidences of the word
   *list;                                            // hash-ordered words list

   int
      listSize,                // size of list[] (may be larger than maxTracks)
      maxWords,                              // maximum number of words allowed
      nWords;                                        // current number of words


   public:
   WordsList(int n);
   ~WordsList();
   int Set(const char *word);


   int Count(int word) {                              // word's incidence count
      return word ? list[word - 1].count : 0; }

   int Count() {                                         // total words in list
      return nWords; }
 };                                                            // END WordsList
